(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     26990,        752]
NotebookOptionsPosition[     25717,        705]
NotebookOutlinePosition[     26164,        723]
CellTagsIndexPosition[     26121,        720]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
Reinforcement Learning Dynamics in Social Dilemmas - Figure 8\
\>", "Title"],

Cell["Luis R. Izquierdo and Segismundo S. Izquierdo", "Subtitle"],

Cell[TextData[{
 "This program was used to generate figure 8 in the paper: \n",
 "Izquierdo, S. S., Izquierdo, L. R. and Gotts, N. M. (2008). Reinforcement \
Learning Dynamics in Social Dilemmas. Journal of Artificial Societies and \
Social Simulation 11(2)1. <",
 ButtonBox["http://jasss.soc.surrey.ac.uk/11/2/1.html",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://jasss.soc.surrey.ac.uk/11/2/1.html"], None}],
 ">",
 "."
}], "Subsubtitle",
 CellChangeTimes->{3.4140422793726254`*^9, 3.4140423851070004`*^9}],

Cell[TextData[{
 "The output of this program is a series of histograms. For each element ",
 StyleBox["i",
  FontSlant->"Italic"],
 " of the vector ",
 StyleBox["reportingList",
  FontWeight->"Bold"],
 " (see section ",
 StyleBox["Parameters", "Section"],
 "), a histogram is created that shows the propensity to cooperate for one \
agent after ",
 StyleBox["i",
  FontSlant->"Italic"],
 " iterations calculated over ",
 StyleBox["runs",
  FontWeight->"Bold"],
 " (see section ",
 StyleBox["Parameters", "Section"],
 ") number of runs. The histograms are saved as files in various formats \
(e.g. png, gif, tiff, and eps).\n",
 StyleBox["IMPORTANT",
  FontWeight->"Bold",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0, 0]],
 ": This program assumes that both agents' propensities change in the same \
way, so calculations are performed only for one of them. This assumption is \
only valid for very specific sets of parameters, and is made here to increase \
the speed of simulations. Changing the program to allow for different \
propensities is straightforward. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Licence", "Section"]], "Section"],

Cell["\<\
Copyright (C) 2007 Luis R. Izquierdo & Segismundo S. Izquierdo

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version. 

This program is distributed in the hope that it will be useful, 
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details. 

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, \
USA.\
\>", "Subsubtitle"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Setting the Environment", "Section"]], "Section"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Graphics`Graphics`\>\"", "]"}], ";"}], "\n", 
 RowBox[{"Off", "[", 
  RowBox[{"General", "::", "spell"}], "]"}]}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Parameters", "Section",
 TextAlignment->Left],

Cell[BoxData[{
 RowBox[{
  RowBox[{"runs", "=", "1000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"reportingList", "=", 
     RowBox[{"8", "^", 
      RowBox[{"{", 
       RowBox[{
       "0", ",", "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", 
        "7"}], "}"}]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]"}], 
  RowBox[{"(*", 
   RowBox[{"Random", " ", "seed"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"SeedRandom", "[", "]"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]"}], 
  RowBox[{"(*", 
   RowBox[{
   "Number", " ", "of", " ", "categories", " ", "in", " ", "the", " ", 
    "histograms"}], "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"categories", " ", "=", " ", "40"}], ";"}], "\n", 
   "\[IndentingNewLine]"}], 
  RowBox[{"(*", 
   RowBox[{"Initial", " ", "Probability"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"initialProb", "=", "0.5"}], ";"}], "\n", "\[IndentingNewLine]"}],
   
  RowBox[{"(*", "Payoffs", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"T", "=", "4"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"R", "=", "3"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"P", "=", "1"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"S", "=", "0"}], ";"}], "\n", "\[IndentingNewLine]"}], 
  RowBox[{"(*", 
   RowBox[{"Aspiration", " ", "Threshold"}], "*)"}]}], "\[IndentingNewLine]", 

 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"A", "=", "2"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]"}], 
  RowBox[{"(*", 
   RowBox[{"Learning", " ", "rate"}], "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"l", "=", 
     RowBox[{"1", "/", "2"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]"}], 
  RowBox[{"(*", "Noise", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"noise", "=", "0"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]"}], 
  RowBox[{"(*", 
   RowBox[{
   "Directory", " ", "where", " ", "the", " ", "figure", " ", "will", " ", 
    "be", " ", "saved"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"SetDirectory", "[", "\"\<C:\\\\temp\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]"}], 
  RowBox[{"(*", 
   RowBox[{"File", " ", "extensions", " ", "required"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"extensions", "=", 
   RowBox[{"{", "\"\<.gif\>\"", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"figureSize", "=", "600"}], ";"}]}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Definition of functions and labels", "Section",
 TextAlignment->Left],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Labels", ".", " ", "This"}], " ", "is", " ", "done", " ", "for", 
    " ", "efficiency", " ", "and", " ", "code", " ", "readability"}], "*)"}], 
  "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"Cooperate", "=", "0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Defect", "=", "1"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"CC", "=", "0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"CD", "=", "1"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"DC", "=", "2"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"DD", "=", "3"}], ";"}], "\n", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Calculation", " ", "of", " ", "possible", " ", 
     RowBox[{"stimuli", ".", " ", "These"}], " ", "operations", " ", "are", 
     " ", "performed", " ", "only", " ", "once", " ", "for", " ", 
     "efficiency"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"divisor", "=", 
     RowBox[{"Max", "[", 
      RowBox[{
       RowBox[{"Abs", "[", 
        RowBox[{"T", "-", "A"}], "]"}], ",", 
       RowBox[{"Abs", "[", 
        RowBox[{"R", "-", "A"}], "]"}], ",", 
       RowBox[{"Abs", "[", 
        RowBox[{"P", "-", "A"}], "]"}], ",", 
       RowBox[{"Abs", "[", 
        RowBox[{"S", "-", "A"}], "]"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"stimulusAfterCC", " ", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"R", "-", "A"}], ")"}], "/", "divisor"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"stimulusAfterCD", " ", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"S", "-", "A"}], ")"}], "/", "divisor"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"stimulusAfterDC", " ", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"T", "-", "A"}], ")"}], "/", "divisor"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"stimulusAfterDD", " ", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"P", "-", "A"}], ")"}], "/", "divisor"}]}], ";"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{"(*", 
    RowBox[{"Stimulus", " ", "after", " ", "a", " ", "certain", " ", 
     RowBox[{"outcome", ".", " ", "This"}], " ", "function", " ", "returns", 
     " ", "the", " ", "stimulus", " ", "after", " ", "a", " ", "given", " ", 
     "outcome", " ", 
     RowBox[{"(", 
      RowBox[{"e", ".", "g", ".", " ", "CD"}], ")"}], " ", "for", " ", "the", 
     " ", "agent", " ", "who", " ", "has", " ", "selected", " ", "the", " ", 
     "action", " ", "indicated", " ", "by", " ", "the", " ", "first", " ", 
     "letter", " ", "of", " ", "the", " ", "outcome", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"e", ".", "g", ".", " ", "C"}], ")"}], "."}]}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"stimulusAfter", "[", "x_", "]"}], ":=", 
     RowBox[{"Switch", "[", 
      RowBox[{
      "x", ",", "\[IndentingNewLine]", "CC", ",", "stimulusAfterCC", ",", 
       "\[IndentingNewLine]", "CD", ",", "stimulusAfterCD", ",", 
       "\[IndentingNewLine]", "DC", ",", "stimulusAfterDC", ",", 
       "\[IndentingNewLine]", "DD", ",", "stimulusAfterDD"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "Changes", " ", "in", " ", "the", " ", "probability", " ", "of", " ", 
      "cooperating", " ", "after", " ", "given", " ", 
      RowBox[{"outcomes", ".", " ", "The"}], " ", "first", " ", "argument", 
      " ", "is", " ", "the", " ", "outcome"}], ",", " ", 
     RowBox[{
     "and", " ", "the", " ", "second", " ", "argument", " ", "is", " ", "the",
       " ", "probability", " ", "to", " ", "be", " ", 
      RowBox[{"updated", ".", " ", "This"}], " ", "function", " ", "returns", 
      " ", "the", " ", "change", " ", "on", " ", "the", " ", "probability", 
      " ", "indicated", " ", "by", " ", "the", " ", "second", " ", "argument",
       " ", "after", " ", "the", " ", "outcome", " ", "indicated", " ", "in", 
      " ", "the", " ", "first", " ", "argument", " ", 
      RowBox[{"(", 
       RowBox[{"e", ".", "g", ".", " ", "CD"}], ")"}], " ", "for", " ", "the",
       " ", "agent", " ", "who", " ", "has", " ", "selected", " ", "the", " ",
       "action", " ", "indicated", " ", "by", " ", "the", " ", "first", " ", 
      "letter", " ", "of", " ", "the", " ", "outcome", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"e", ".", "g", ".", " ", "C"}], ")"}], "."}]}]}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"changeAfterOn", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], ":=", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "\[Equal]", "CC"}], ")"}], "||", 
        RowBox[{"(", 
         RowBox[{"x", "\[Equal]", "CD"}], ")"}]}], ",", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{"Agent", " ", "has", " ", "cooperated"}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"stimulusAfter", "[", "x", "]"}], "\[GreaterEqual]", "0"}], 
         ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "y"}], ")"}], "*", "l", "*", 
          RowBox[{"stimulusAfter", "[", "x", "]"}]}], ",", 
         RowBox[{"y", "*", "l", "*", 
          RowBox[{"stimulusAfter", "[", "x", "]"}]}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{"Agent", " ", "has", " ", "defected"}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"stimulusAfter", "[", "x", "]"}], "\[GreaterEqual]", "0"}], 
         ",", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{"y", "*", "l", "*", 
            RowBox[{"stimulusAfter", "[", "x", "]"}]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"1", "-", "y"}], ")"}]}], "*", "l", "*", 
          RowBox[{"stimulusAfter", "[", "x", "]"}]}]}], "]"}]}], 
      "\[IndentingNewLine]", "]"}]}], ";"}]}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Initialisation", "Section",
 TextAlignment->Left],

Cell[BoxData[{
 RowBox[{
  RowBox[{"noOfReports", "=", 
   RowBox[{"Length", "[", "reportingList", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"iterationsPerRun", "=", 
   RowBox[{"reportingList", "[", 
    RowBox[{"[", "noOfReports", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 

 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"control", " ", "=", " ", 
     RowBox[{"Ceiling", "[", 
      RowBox[{"runs", " ", "/", " ", "noOfReports"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]"}], 
  RowBox[{"(*", 
   RowBox[{
   "Vector", " ", "with", " ", "the", " ", "decisions", " ", "undertaken", 
    " ", "by", " ", "each", " ", "of", " ", "the", " ", "agents"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"decisions", "=", 
     RowBox[{"{", ",", "}"}]}], ";"}], "\n", "\[IndentingNewLine]"}], 
  RowBox[{"(*", 
   RowBox[{
   "Initialisation", " ", "of", " ", "the", " ", "list", " ", "of", " ", 
    "histograms"}], "*)"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"histoList", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", "noOfReports", "}"}], ",", 
     RowBox[{"{", "categories", "}"}]}], "]"}]}], ";"}]}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Actual program", "Section",
 TextAlignment->Left],

Cell[BoxData[
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"j", "=", "1"}], ",", 
    RowBox[{"j", "\[LessEqual]", "runs"}], ",", 
    RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Mod", "[", 
         RowBox[{"j", ",", "control"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"Print", "[", 
         RowBox[{"\"\<Starting run \>\"", ",", " ", "j"}], "]"}], ";", 
        RowBox[{"Print", "[", 
         RowBox[{"Date", "[", "]"}], "]"}], ";"}]}], "]"}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"prob1", "=", "initialProb"}], ";", "\[IndentingNewLine]", 
     RowBox[{"histoCounter", "=", "1"}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"i", "\[LessEqual]", "iterationsPerRun"}], ",", 
       RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]",
        
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Random", "[", "]"}], "\[LessEqual]", "prob1"}], ",", 
          RowBox[{
           RowBox[{"decisions", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "=", "Cooperate"}], ",", 
          RowBox[{
           RowBox[{"decisions", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "=", "Defect"}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", 
         RowBox[{"Now", " ", "include", " ", "noise"}], "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"noise", "\[NotEqual]", "0"}], ",", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Random", "[", "]"}], "\[LessEqual]", "noise"}], ",", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"decisions", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "Cooperate"}], 
              ",", 
              RowBox[{
               RowBox[{"decisions", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "=", "Defect"}], ",", 
              RowBox[{
               RowBox[{"decisions", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "=", "Cooperate"}]}], "]"}]}],
            "]"}]}], "]"}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]",
         
        RowBox[{"(*", 
         RowBox[{
         "Remember", " ", "that", " ", "it", " ", "is", " ", "assumed", " ", 
          "that", " ", 
          RowBox[{"agents", "'"}], " ", "probabilities", " ", "are", " ", 
          "the", " ", "same"}], "*)"}], "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Random", "[", "]"}], "<", "prob1"}], ",", 
          RowBox[{
           RowBox[{"decisions", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "=", "Cooperate"}], ",", 
          RowBox[{
           RowBox[{"decisions", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "=", "Defect"}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", 
         RowBox[{"Now", " ", "include", " ", "noise"}], "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"noise", "\[NotEqual]", "0"}], ",", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Random", "[", "]"}], "\[LessEqual]", "noise"}], ",", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"decisions", "[", 
                RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "Cooperate"}], 
              ",", 
              RowBox[{
               RowBox[{"decisions", "[", 
                RowBox[{"[", "2", "]"}], "]"}], "=", "Defect"}], ",", 
              RowBox[{
               RowBox[{"decisions", "[", 
                RowBox[{"[", "2", "]"}], "]"}], "=", "Cooperate"}]}], "]"}]}],
            "]"}]}], "]"}], ";", " ", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", 
         RowBox[{
         "We", " ", "only", " ", "calculate", " ", "the", " ", "new", " ", 
          "probability", " ", "for", " ", "one", " ", "player", " ", 
          "because", " ", "it", " ", "is", " ", "assumed", " ", "that", " ", 
          "both", " ", "probabilities", " ", "are", " ", "always", " ", "the",
           " ", "same"}], "*)"}], "\[IndentingNewLine]", 
        RowBox[{"outcome", "=", 
         RowBox[{"Switch", "[", 
          RowBox[{"decisions", ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"Cooperate", ",", "Cooperate"}], "}"}], ",", "CC", ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"Cooperate", ",", "Defect"}], "}"}], ",", "CD", ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"Defect", ",", "Cooperate"}], "}"}], ",", "DC", ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"Defect", ",", "Defect"}], "}"}], ",", "DD"}], "]"}]}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"prob1", "=", 
         RowBox[{"prob1", "+", 
          RowBox[{"changeAfterOn", "[", 
           RowBox[{"outcome", ",", "prob1"}], "]"}]}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"(*", "Report", "*)"}], "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"i", "\[Equal]", 
           RowBox[{"reportingList", "[", 
            RowBox[{"[", "histoCounter", "]"}], "]"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Ceiling", "[", 
               RowBox[{"prob1", "*", "categories"}], "]"}], "\[LessEqual]", 
              "0"}], ",", 
             RowBox[{
              RowBox[{"histoList", "[", 
               RowBox[{"[", 
                RowBox[{"histoCounter", ",", "1"}], "]"}], "]"}], "++"}], ",",
              
             RowBox[{
              RowBox[{"histoList", "[", 
               RowBox[{"[", 
                RowBox[{"histoCounter", ",", 
                 RowBox[{"Ceiling", "[", 
                  RowBox[{"prob1", "*", "categories"}], "]"}]}], "]"}], "]"}],
               "++"}]}], "]"}], ";", "\[IndentingNewLine]", 
           RowBox[{"(*", 
            RowBox[{
             RowBox[{"Print", "[", 
              RowBox[{
              "\"\<Reporting after iteration \>\"", ",", " ", "i", ",", " ", 
               "\"\< for histogram \>\"", ",", " ", "histoCounter"}], "]"}], 
             ";"}], "*)"}], "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"histoCounter", "<", "noOfReports"}], ",", 
             RowBox[{"histoCounter", "++"}]}], "]"}], ";"}]}], 
         "\[IndentingNewLine]", "]"}], ";"}]}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"Print", "[", 
         RowBox[{"\"\<End of iteration \>\"", ",", "i"}], "]"}], ";"}], 
       "*)"}], "\[IndentingNewLine]", "]"}], ";"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"Print", "[", 
      RowBox[{"\"\<End of run \>\"", ",", " ", "j"}], "]"}], ";"}], "*)"}], 
   "\[IndentingNewLine]", "]"}], ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Show figures and write them to file", "Section",
 TextAlignment->Left],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Create", " ", "a", " ", "new", " ", "Directory"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"newDirectory", "=", 
     RowBox[{"StringJoin", "[", 
      RowBox[{"\"\<./l\>\"", ",", 
       RowBox[{"ToString", "[", 
        RowBox[{"Numerator", "[", "l", "]"}], "]"}], ",", "\"\<-\>\"", ",", 
       RowBox[{"ToString", "[", 
        RowBox[{"Denominator", "[", "l", "]"}], "]"}]}], "]"}]}], ";"}], "\n",
    
   RowBox[{
    RowBox[{"newDirectory", "=", 
     RowBox[{"StringJoin", "[", 
      RowBox[{"newDirectory", ",", " ", "\"\<_A\>\"", ",", 
       RowBox[{"ToString", "[", "A", "]"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"noise", "\[NotEqual]", "0"}], ",", 
      RowBox[{"newDirectory", "=", 
       RowBox[{"StringJoin", "[", 
        RowBox[{"newDirectory", ",", " ", "\"\<_n\>\"", ",", 
         RowBox[{"ToString", "[", 
          RowBox[{"Numerator", "[", "noise", "]"}], "]"}], ",", "\"\<-\>\"", 
         ",", 
         RowBox[{"ToString", "[", 
          RowBox[{"Denominator", "[", "noise", "]"}], "]"}]}], "]"}]}]}], 
     "]"}], ";"}], "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"CreateDirectory", "[", "newDirectory", "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"SetDirectory", "[", "newDirectory", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"numberOfExtensions", "=", "  ", 
     RowBox[{"Length", "[", "extensions", "]"}]}], ";"}], "\n", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"histoCategories", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"k", "/", "categories"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", "categories"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "\[LessEqual]", "noOfReports"}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      
      RowBox[{"(*", 
       RowBox[{"Make", " ", "it", " ", "proportions"}], "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"histoList", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "/=", "runs"}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<Histogram after iteration \>\"", ",", " ", 
         RowBox[{"reportingList", "[", 
          RowBox[{"[", "i", "]"}], "]"}], ",", " ", 
         "\"\< calculated over \>\"", ",", " ", "runs", " ", ",", " ", 
         "\"\< runs\>\""}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"fileName", "=", " ", 
        RowBox[{"StringJoin", "[", 
         RowBox[{
          RowBox[{"StringDrop", "[", 
           RowBox[{"newDirectory", ",", "2"}], "]"}], ",", "\"\<_i\>\"", ",", 
          
          RowBox[{"ToString", "[", " ", 
           RowBox[{"reportingList", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", "\"\<_r\>\"", ",", 
          RowBox[{"ToString", "[", "runs", "]"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"j", "=", "1"}], ",", " ", 
         RowBox[{"j", "\[LessEqual]", "numberOfExtensions"}], ",", 
         RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Export", "[", 
           RowBox[{
            RowBox[{"StringJoin", "[", 
             RowBox[{"fileName", ",", 
              RowBox[{"extensions", "[", 
               RowBox[{"[", "j", "]"}], "]"}]}], "]"}], ",", 
            RowBox[{"Graphics`Graphics`Histogram", "[", 
             RowBox[{
              RowBox[{"histoList", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", 
              RowBox[{"FrequencyData", "\[Rule]", "True"}], ",", 
              RowBox[{"HistogramCategories", "\[Rule]", "histoCategories"}]}],
              "]"}], ",", 
            RowBox[{"ImageSize", "\[Rule]", "figureSize"}]}], "]"}], ";"}]}], 
        "\[IndentingNewLine]", "]"}], ";"}]}], "\[IndentingNewLine]", 
     "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Date", "[", "]"}], "]"}], ";"}]}]}]], "Input"]
}, Closed]]
},
CellGrouping->Manual,
WindowSize->{1432, 791},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
DockedCells->FEPrivate`FrontEndResource[
 "FEExpressions", "CompatibilityToolbar"],
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"DemoText.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 86, 2, 56, "Title"],
Cell[657, 25, 65, 0, 37, "Subtitle"],
Cell[725, 27, 521, 12, 73, "Subsubtitle"],
Cell[1249, 41, 1097, 29, 103, "Text"],
Cell[CellGroupData[{
Cell[2371, 74, 57, 0, 52, "Section"],
Cell[2431, 76, 779, 17, 310, "Subsubtitle"]
}, Closed]],
Cell[CellGroupData[{
Cell[3247, 98, 73, 0, 32, "Section"],
Cell[3323, 100, 177, 4, 60, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[3537, 109, 51, 1, 32, "Section"],
Cell[3591, 112, 2621, 85, 680, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[6249, 202, 75, 1, 32, "Section"],
Cell[6327, 205, 6042, 150, 680, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[12406, 360, 55, 1, 32, "Section"],
Cell[12464, 363, 1236, 36, 200, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[13737, 404, 55, 1, 32, "Section"],
Cell[13795, 407, 7468, 181, 780, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[21300, 593, 76, 1, 32, "Section"],
Cell[21379, 596, 4322, 106, 540, "Input"]
}, Closed]]
}
]
*)

(* End of internal cache information *)
